==> haskell-text-printer-0.5.0.2-93-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-printer
version:              0.5.0.2
visibility:           public
id:                   text-printer-0.5.0.2-B7Cn8d1wLbbJ4jRkvJCcbQ
key:                  text-printer-0.5.0.2-B7Cn8d1wLbbJ4jRkvJCcbQ
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-printer
synopsis:             Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.

category:             Text
abi:                  244ff24942c22e9b47f04b448578a35a
exposed:              True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral

import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-printer-0.5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-printer-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-printer
hs-libraries:         HStext-printer-0.5.0.2-B7Cn8d1wLbbJ4jRkvJCcbQ
depends:
    base-4.16.4.0 bytestring-0.11.4.0 pretty-1.1.3.6 text-1.2.5.0
    text-latin1-0.3.1-vuw8PxaGIp9aHVute3kXR

haddock-interfaces:
    /usr/share/doc/haskell-text-printer/html/text-printer.haddock

haddock-html:         /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-printer-0.5.0.2-95-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-printer
version:              0.5.0.2
visibility:           public
id:                   text-printer-0.5.0.2-BIh3wiJfIHK7sWc3xqP5Ff
key:                  text-printer-0.5.0.2-BIh3wiJfIHK7sWc3xqP5Ff
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-printer
synopsis:             Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.

category:             Text
abi:                  6ec18331fc4e9a07423ed193ae4b5ca5
exposed:              True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral

import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-printer-0.5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-printer-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-printer
hs-libraries:         HStext-printer-0.5.0.2-BIh3wiJfIHK7sWc3xqP5Ff
depends:
    base-4.16.4.0 bytestring-0.11.4.0 pretty-1.1.3.6 text-1.2.5.0
    text-latin1-0.3.1-eddX6rd3rE4Ec9P7DfFGE

haddock-interfaces:
    /usr/share/doc/haskell-text-printer/html/text-printer.haddock

haddock-html:         /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
